[vlc-devel] [PATCH] decoder: Increase fifo size up to 250 Mb/s

Nicolas Bertrand nicoinattendu at gmail.com
Tue Jul 16 15:05:10 CEST 2013


Changed to support DCP compression bit-rate (Max is 250 Mb/s).
1800 MiB ~ 1788 MiB = ( (250 * 60s) * 1e6) / ( 8 *2**20)
---
 src/input/decoder.c |    2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/input/decoder.c b/src/input/decoder.c
index b1b038c..e548577 100644
--- a/src/input/decoder.c
+++ b/src/input/decoder.c
@@ -396,7 +396,7 @@ void input_DecoderDecode( decoder_t *p_dec, block_t *p_block, bool b_do_pace )
 #ifdef __arm__
     else if( block_FifoSize( p_owner->p_fifo ) > 50*1024*1024 /* 50 MiB */ )
 #else
-    else if( block_FifoSize( p_owner->p_fifo ) > 400*1024*1024 /* 400 MiB, ie ~ 50mb/s for 60s */ )
+    else if( block_FifoSize( p_owner->p_fifo ) > 1800*1024*1024 /* 1800 MiB, ie ~ 250mb/s for 60s */ )
 #endif
     {
         /* FIXME: ideally we would check the time amount of data
-- 
1.7.9.5




More information about the vlc-devel mailing list